@@ -29,12 +29,12 @@ from lava_test.core.runners import TestRunner
 from lava_test.core.tests import Test
 
 DEFAULT_OPTIONS = ""
-INSTALLSTEPS = ['bzr branch lp:~linaro-foundations/lava-test/bootchartscript']
+BZR_REPOS = ['lp:~linaro-foundations/lava-test/bootchartscript']
 DEPS = ['bootchart', 'pybootchartgui', 'bzr']
 RUNSTEPS = ['./bootchartscript/bootchartscript.sh $(OPTIONS)']
 PATTERN = "^(?P<test_case_id>\w+):\W+(?P<measurement>\d+\.\d+)"
 
-installer = TestInstaller(INSTALLSTEPS, deps=DEPS)
+installer = TestInstaller(deps=DEPS, bzr_repos=BZR_REPOS)
 runner = TestRunner(RUNSTEPS, default_options=DEFAULT_OPTIONS)
 parser = TestParser(PATTERN, appendall={'units': 'sec', 'result': 'pass'})
 
